@@ -42,15 +42,16 @@ class Authorization:
             login_url = "{}login".format(url)
             r = requests.get(url=login_url, params={"login": user_name})
             if not r.ok:
-                msg = 'Invalid server response (URL: {}, Code: {}, Reason: "{}", Text: {})'.format(
-                    login_url, r.status_code, r.reason, '<empty>' if not r.text else r.text)
+                msg = 'Stand "{}" not supporting non-password authorization. Please, specify the password! ' \
+                    'Details: Code: {}, Reason: "{}", Text: {}'.format(
+                        url, r.status_code, r.reason, '<empty>' if not r.text else r.text)
                 raise AuthError(msg)
             else:
                 try:
                     response = r.json()
                 except json.decoder.JSONDecodeError:
-                    msg = 'Stand "{}" not supporting non-password authorization. Please, specify the password!'.format(
-                        url)
+                    msg = 'Invalid server response! Details: URL: {}, Code: {}, Reason: "{}", Text: {}'.format(
+                        login_url, r.status_code, r.reason, '<empty>' if not r.text else r.text)
                     raise AuthError(msg)
             if len(r.history) > 0:
                 for resp in r.history:
