@@ -20,6 +20,9 @@ self.full_polymatica_version
 # По-умолчанию "ru"
 self.language
 
+# Базовый URL стенда Полиматики (тот, что передаётся в конструктор при инициализации класса)
+self.base_url
+
 # Таймаут выполнения запросов
 self.timeout
 
