@@ -338,13 +338,14 @@ def checks(self, func_name, *args):
             if "day" in update_params["schedule"]:
                 if update_params["schedule"]["day"] > 31:
                     raise ValueError("Неверный день месяца: %s !" % update_params["schedule"]["day"])
+        self.func_name = 'create_sphere'
         return True
     elif func_name == "execute_olap_command":
         if self.multisphere_module_id == "":
             raise ValueError("First create cube and get data from it!")
         return True
     elif func_name == 'load_sphere_chunk':
-        units = args[0]
+        units, convert_type, convert_empty_values = args[0], args[1], args[2]
         is_int = False
         error_msg = 'Param "units" must be a positive integer number!'
         try:
@@ -353,6 +354,10 @@ def checks(self, func_name, *args):
             raise ValueError(error_msg)
         if not is_int or int(units) <= 0:
             raise ValueError(error_msg)
+        if not isinstance(convert_type, bool):
+            raise ValueError('Param "convert_type" can only be boolean: True / False!')
+        if not isinstance(convert_empty_values, bool):
+            raise ValueError('Param "convert_empty_values" can only be boolean: True / False!')
     elif func_name == 'set_measure_level':
         level, left_dims_count = args[0], args[1]
         error_msg = str()
@@ -377,5 +382,19 @@ def checks(self, func_name, *args):
         is_horizontal = args[0]
         if is_horizontal not in [True, False]:
             raise ValueError('Param "is_horizontal" must be "True" or "False"!')
+    elif func_name == 'get_scenario_metadata':
+        script_id = args[0]
+        if not isinstance(script_id, str):
+            raise ValueError('Param "script_id" must be string type!')
+        if not script_id:
+            raise ValueError('Param "script_id" not set!')
+    elif func_name == 'reset_filters':
+        dimensions = args[0]
+        if isinstance(dimensions, str):
+            return [dimensions] if dimensions else []
+        elif isinstance(dimensions, (list, tuple)):
+            return dimensions
+        else:
+            raise ValueError('Param "dimensions" must be "str", "list" or "tuple" type!')
     else:
         raise ValueError("No function to check: {}".format(func_name))
