@@ -178,7 +178,7 @@ class Executor:
     def get_server_codes(base_url) -> Dict:
         """
         Получение GET-запросом списка команд и состояний, которые используются в Полиматике.
-        :param base_url: (str) URL-адрес стенда Полиматики.
+        :param base_url: (str) базовый URL-адрес стенда Полиматики.
         :return: словарь списков и состояний, расположенный по пути base_url/server-codes.json.
         """
         r = requests.get('{}server-codes.json'.format(base_url))
